enum AdjustMode {
Peel {
kind: PeelKind,
},
Pass,
}Expand description
Mode for adjusting the expected type and binding mode.
Variants
Peel
Peel off all immediate reference types. If the deref_patterns feature is enabled, this
also peels smart pointer ADTs.
Pass
Pass on the input binding mode and expected type.
Implementations
Sourceimpl AdjustMode
impl AdjustMode
const fn peel_until_adt(opt_adt_def: Option<AdtId>) -> AdjustMode
const fn peel_all() -> AdjustMode