enum PeelKind {
ExplicitDerefPat,
Implicit {
until_adt: Option<AdtId>,
pat_ref_layers: usize,
},
}Expand description
Restrictions on what types to peel when adjusting the expected type and binding mode.
Variants
ExplicitDerefPat
Only peel reference types. This is used for explicit deref!(_) patterns, which dereference
any number of &/&mut references, plus a single smart pointer.
Implicit
Implicitly peel references, and if deref_patterns is enabled, smart pointer ADTs.
Fields

until_adt: Option<AdtId>The ADT the pattern is a constructor for, if applicable, so that we don’t peel it. See
ResolvedPat for more information.